package prioritysearch;

import jdsl.core.api.*;
import jdsl.core.ref.*;
import jdsl.geomobj.api.*;
import jdsl.geomobj.ref.*;

/** An implementation of the priority search tree for a range bounded 
    on three sides. */

public interface PrioritySearchTree
{
    /** Initializes the priority search tree for searches over ranges 
	with three sides.
	@param comp1 comparator for the bounded direction.
	@param comp2 comparator for the one-sided (open) direction.
	@param oi an iterator over the objects to query.
	@throws RunTimeException if the input objects cannot be 
	compared by both comparators
    */
    public void initialize(Comparator comp1, Comparator comp2,
			   ObjectIterator oi) throws RuntimeException;
	
    /** Queries the search tree within a three-sided range.
	Objects equal to the bounds are considered to be within the 
	search range.
	@param min1 an object indicating the bottom of the bounded 
	direction's range.
	@param max1 an object indicating the top of the bounded direction's
	range.
	@param min2 an object indicating the bottom of the one-sided
	(open) direction's range.
	@return an iterator over the objects in the range.
	@throws RunTimeException if the input objects are not of the right 
	type (that is, they cannot be compared by the initialized comparators).
    */
    public ObjectIterator query(Object min1, Object max1, Object min2)
	throws RuntimeException;
}
